@@ -1,5 +1,5 @@
 from django import forms
-from edc_constants.constants import NO, YES
+from edc_constants.constants import YES
 
 from edc_form_validators.form_validator import FormValidator
 from edc_form_validators.form_validator_mixin import FormValidatorMixin
